You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by jc...@apache.org on 2007/04/10 20:54:58 UTC

svn commit: r527247 [7/8] - in /incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src: main/java/ main/java/org/ main/java/org/apache/ main/java/org/apache/wicket/ main/java/org/apache/wicket/authentication/ main/java/org/apache/wicket/authe...

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/stockquote/StockQuotePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/stockquote/StockQuotePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/stockquote/StockQuotePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/stockquote/StockQuotePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/stockquote/StockQuotePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/stockquote/StockQuotePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/stockquote/StockQuotePage.java Tue Apr 10 11:54:24 2007
@@ -14,15 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.stockquote;
+package org.apache.wicket.examples.stockquote;
+
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.model.PropertyModel;
 
-import wicket.IClusterable;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.TextField;
-import wicket.model.IModel;
-import wicket.model.PropertyModel;
 
 /**
  * Stock quote webservice custom component example.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Banner.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Banner.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Banner.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner.java Tue Apr 10 11:54:24 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.template;
+package org.apache.wicket.examples.template;
 
-import wicket.markup.html.panel.Panel;
-import wicket.model.IModel;
+import org.apache.wicket.markup.html.panel.Panel;
+import org.apache.wicket.model.IModel;
 
 /**
  * Base class for banners.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner1.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Banner1.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner1.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Banner1.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner1.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Banner1.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner1.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.template;
+package org.apache.wicket.examples.template;
 
-import wicket.model.IModel;
+import org.apache.wicket.model.IModel;
 
 /**
  * A banner.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner2.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Banner2.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner2.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Banner2.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner2.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Banner2.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Banner2.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.template;
+package org.apache.wicket.examples.template;
 
-import wicket.model.IModel;
+import org.apache.wicket.model.IModel;
 
 /**
  * A banner.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Page1.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Page1.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Page1.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Page1.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Page1.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Page1.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Page1.java Tue Apr 10 11:54:24 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.template;
+package org.apache.wicket.examples.template;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Page2.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Page2.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Page2.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Page2.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Page2.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Page2.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Page2.java Tue Apr 10 11:54:24 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.template;
+package org.apache.wicket.examples.template;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Panel1.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Panel1.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Panel1.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Panel1.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Panel1.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/Panel1.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/Panel1.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.template;
+package org.apache.wicket.examples.template;
 
-import wicket.model.IModel;
+import org.apache.wicket.model.IModel;
 
 /**
  * Concrete, extending panel.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplateApplication.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/TemplateApplication.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplateApplication.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/TemplateApplication.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplateApplication.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/TemplateApplication.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplateApplication.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.template;
+package org.apache.wicket.examples.template;
 
-import wicket.examples.WicketExampleApplication;
+import org.apache.wicket.examples.WicketExampleApplication;
 
 /**
  * Application class for the template example.
@@ -33,7 +33,7 @@
 	}
 
 	/**
-	 * @see wicket.Application#getHomePage()
+	 * @see org.apache.wicket.Application#getHomePage()
 	 */
 	public Class getHomePage()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplatePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/TemplatePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplatePage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/TemplatePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplatePage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/TemplatePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplatePage.java Tue Apr 10 11:54:24 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.template;
+package org.apache.wicket.examples.template;
+
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.link.BookmarkablePageLink;
+import org.apache.wicket.markup.html.link.Link;
+import org.apache.wicket.model.PropertyModel;
 
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.link.BookmarkablePageLink;
-import wicket.markup.html.link.Link;
-import wicket.model.PropertyModel;
 
 /**
  * Our base page that serves as a template for pages that inherit from it.
@@ -47,7 +48,7 @@
 		add(new Link("changeAdLink")
 		{
 			/**
-			 * @see wicket.markup.html.link.Link#onClick()
+			 * @see org.apache.wicket.markup.html.link.Link#onClick()
 			 */
 			public void onClick()
 			{
@@ -87,7 +88,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#isVersioned()
+	 * @see org.apache.wicket.Component#isVersioned()
 	 */
 	public boolean isVersioned()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplatePanel.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/TemplatePanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplatePanel.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/TemplatePanel.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplatePanel.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/template/TemplatePanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/template/TemplatePanel.java Tue Apr 10 11:54:24 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.template;
+package org.apache.wicket.examples.template;
 
-import wicket.markup.html.panel.Panel;
-import wicket.model.IModel;
+import org.apache.wicket.markup.html.panel.Panel;
+import org.apache.wicket.model.IModel;
 
 /**
  * Base panel to be extended.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/unicodeconverter/UnicodeConverter.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/unicodeconverter/UnicodeConverter.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/unicodeconverter/UnicodeConverter.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/unicodeconverter/UnicodeConverter.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/unicodeconverter/UnicodeConverter.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/unicodeconverter/UnicodeConverter.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/unicodeconverter/UnicodeConverter.java Tue Apr 10 11:54:24 2007
@@ -14,19 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.unicodeconverter;
+package org.apache.wicket.examples.unicodeconverter;
 
 import java.util.Arrays;
 import java.util.List;
 
-import wicket.Component;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.form.DropDownChoice;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.TextArea;
-import wicket.model.CompoundPropertyModel;
-import wicket.model.Model;
-import wicket.util.string.Strings;
+import org.apache.wicket.Component;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.form.DropDownChoice;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.TextArea;
+import org.apache.wicket.model.CompoundPropertyModel;
+import org.apache.wicket.model.Model;
+import org.apache.wicket.util.string.Strings;
+
 
 /**
  * Converts between unescaped and escaped unicode and shows a custom model.
@@ -63,7 +64,7 @@
 	private final class ConverterModel extends Model
 	{
 		/**
-		 * @see wicket.model.IModel#getObject()
+		 * @see org.apache.wicket.model.IModel#getObject()
 		 */
 		public Object getObject()
 		{
@@ -80,7 +81,7 @@
 		}
 
 		/**
-		 * @see wicket.model.IModel#setObject(java.lang.Object)
+		 * @see org.apache.wicket.model.IModel#setObject(java.lang.Object)
 		 */
 		public void setObject(Object object)
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/unicodeconverter/UnicodeConverterApplication.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/unicodeconverter/UnicodeConverterApplication.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/unicodeconverter/UnicodeConverterApplication.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/unicodeconverter/UnicodeConverterApplication.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/unicodeconverter/UnicodeConverterApplication.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/unicodeconverter/UnicodeConverterApplication.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/unicodeconverter/UnicodeConverterApplication.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.unicodeconverter;
+package org.apache.wicket.examples.unicodeconverter;
 
-import wicket.examples.WicketExampleApplication;
+import org.apache.wicket.examples.WicketExampleApplication;
 
 /**
  * Application class for the unicode converter example.
@@ -33,7 +33,7 @@
 	}
 
 	/**
-	 * @see wicket.Application#getHomePage()
+	 * @see org.apache.wicket.Application#getHomePage()
 	 */
 	public Class getHomePage()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/MultiUploadPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/upload/MultiUploadPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/MultiUploadPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/upload/MultiUploadPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/MultiUploadPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/upload/MultiUploadPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/MultiUploadPage.java Tue Apr 10 11:54:24 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.upload;
+package org.apache.wicket.examples.upload;
 
 import java.io.File;
 import java.util.ArrayList;
@@ -24,24 +24,24 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.upload.FileUpload;
+import org.apache.wicket.markup.html.form.upload.MultiFileUploadField;
+import org.apache.wicket.markup.html.link.Link;
+import org.apache.wicket.markup.html.list.ListItem;
+import org.apache.wicket.markup.html.list.ListView;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.model.LoadableDetachableModel;
+import org.apache.wicket.model.PropertyModel;
+import org.apache.wicket.util.file.Files;
+import org.apache.wicket.util.file.Folder;
+import org.apache.wicket.util.lang.Bytes;
 
-import wicket.Application;
-import wicket.PageParameters;
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.upload.FileUpload;
-import wicket.markup.html.form.upload.MultiFileUploadField;
-import wicket.markup.html.link.Link;
-import wicket.markup.html.list.ListItem;
-import wicket.markup.html.list.ListView;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.IModel;
-import wicket.model.LoadableDetachableModel;
-import wicket.model.PropertyModel;
-import wicket.util.file.Files;
-import wicket.util.file.Folder;
-import wicket.util.lang.Bytes;
 
 /**
  * Upload example.
@@ -124,7 +124,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.Form#onSubmit()
+		 * @see org.apache.wicket.markup.html.form.Form#onSubmit()
 		 */
 		protected void onSubmit()
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/UploadApplication.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/upload/UploadApplication.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/UploadApplication.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/upload/UploadApplication.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/UploadApplication.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/upload/UploadApplication.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/UploadApplication.java Tue Apr 10 11:54:24 2007
@@ -14,17 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.upload;
+package org.apache.wicket.examples.upload;
 
 import javax.servlet.http.HttpServletRequest;
 
-import wicket.examples.WicketExampleApplication;
-import wicket.extensions.ajax.markup.html.form.upload.UploadWebRequest;
-import wicket.protocol.http.WebRequest;
-import wicket.util.file.Folder;
+import org.apache.wicket.examples.WicketExampleApplication;
+import org.apache.wicket.extensions.ajax.markup.html.form.upload.UploadWebRequest;
+import org.apache.wicket.protocol.http.WebRequest;
+import org.apache.wicket.util.file.Folder;
+
 
 /**
- * Application class for wicket.examples.upload example.
+ * Application class for org.apache.wicket.examples.upload example.
  * 
  * @author Eelco Hillenius
  */
@@ -41,7 +42,7 @@
 
 
 	/**
-	 * @see wicket.Application#getHomePage()
+	 * @see org.apache.wicket.Application#getHomePage()
 	 */
 	public Class getHomePage()
 	{
@@ -57,13 +58,13 @@
 	}
 
 	/**
-	 * @see wicket.examples.WicketExampleApplication#init()
+	 * @see org.apache.wicket.examples.WicketExampleApplication#init()
 	 */
 	protected void init()
 	{
 		getResourceSettings().setThrowExceptionOnMissingResource(false);
 
-		uploadFolder = new Folder(System.getProperty("java.io.tmpdir"), "wicket-uploads");
+		uploadFolder = new Folder(System.getProperty("java.io.tmpdir"), "org.apache.wicket-uploads");
 		// Ensure folder exists
 		uploadFolder.mkdirs();
 
@@ -73,7 +74,7 @@
 	}
 
 	/**
-	 * @see wicket.protocol.http.WebApplication#newWebRequest(javax.servlet.http.HttpServletRequest)
+	 * @see org.apache.wicket.protocol.http.WebApplication#newWebRequest(javax.servlet.http.HttpServletRequest)
 	 */
 	protected WebRequest newWebRequest(HttpServletRequest servletRequest)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/UploadPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/upload/UploadPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/UploadPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/upload/UploadPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/UploadPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/upload/UploadPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/upload/UploadPage.java Tue Apr 10 11:54:24 2007
@@ -14,31 +14,31 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.upload;
+package org.apache.wicket.examples.upload;
 
 import java.io.File;
 import java.util.Arrays;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.extensions.ajax.markup.html.form.upload.UploadProgressBar;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.upload.FileUpload;
+import org.apache.wicket.markup.html.form.upload.FileUploadField;
+import org.apache.wicket.markup.html.link.Link;
+import org.apache.wicket.markup.html.list.ListItem;
+import org.apache.wicket.markup.html.list.ListView;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.model.LoadableDetachableModel;
+import org.apache.wicket.util.file.Files;
+import org.apache.wicket.util.file.Folder;
+import org.apache.wicket.util.lang.Bytes;
 
-import wicket.Application;
-import wicket.PageParameters;
-import wicket.examples.WicketExamplePage;
-import wicket.extensions.ajax.markup.html.form.upload.UploadProgressBar;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.upload.FileUpload;
-import wicket.markup.html.form.upload.FileUploadField;
-import wicket.markup.html.link.Link;
-import wicket.markup.html.list.ListItem;
-import wicket.markup.html.list.ListView;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.IModel;
-import wicket.model.LoadableDetachableModel;
-import wicket.util.file.Files;
-import wicket.util.file.Folder;
-import wicket.util.lang.Bytes;
 
 /**
  * Upload example.
@@ -111,7 +111,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.Form#onSubmit()
+		 * @see org.apache.wicket.markup.html.form.Form#onSubmit()
 		 */
 		protected void onSubmit()
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/Index.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/Index.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/Index.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/Index.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/Index.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/Index.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/Index.java Tue Apr 10 11:54:24 2007
@@ -14,10 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.wizard;
+package org.apache.wicket.examples.wizard;
+
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.markup.html.link.Link;
 
-import wicket.examples.WicketExamplePage;
-import wicket.markup.html.link.Link;
 
 /**
  * Index page for the wizard example.
@@ -55,7 +56,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.link.Link#onClick()
+		 * @see org.apache.wicket.markup.html.link.Link#onClick()
 		 */
 		public void onClick()
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/NewUserWizard.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/NewUserWizard.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/NewUserWizard.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/NewUserWizard.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/NewUserWizard.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/NewUserWizard.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/NewUserWizard.java Tue Apr 10 11:54:24 2007
@@ -14,31 +14,32 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.wizard;
+package org.apache.wicket.examples.wizard;
 
 import java.util.Arrays;
 import java.util.List;
 
-import wicket.extensions.wizard.StaticContentStep;
-import wicket.extensions.wizard.Wizard;
-import wicket.extensions.wizard.WizardModel;
-import wicket.extensions.wizard.WizardStep;
-import wicket.extensions.wizard.WizardModel.ICondition;
-import wicket.markup.html.form.CheckBox;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.FormComponent;
-import wicket.markup.html.form.ListMultipleChoice;
-import wicket.markup.html.form.RequiredTextField;
-import wicket.markup.html.form.TextField;
-import wicket.markup.html.form.validation.AbstractFormValidator;
-import wicket.model.CompoundPropertyModel;
-import wicket.model.IModel;
-import wicket.model.Model;
-import wicket.model.ResourceModel;
-import wicket.model.StringResourceModel;
-import wicket.validation.IValidationError;
-import wicket.validation.ValidationError;
-import wicket.validation.validator.EmailAddressValidator;
+import org.apache.wicket.extensions.wizard.StaticContentStep;
+import org.apache.wicket.extensions.wizard.Wizard;
+import org.apache.wicket.extensions.wizard.WizardModel;
+import org.apache.wicket.extensions.wizard.WizardStep;
+import org.apache.wicket.extensions.wizard.WizardModel.ICondition;
+import org.apache.wicket.markup.html.form.CheckBox;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.FormComponent;
+import org.apache.wicket.markup.html.form.ListMultipleChoice;
+import org.apache.wicket.markup.html.form.RequiredTextField;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.markup.html.form.validation.AbstractFormValidator;
+import org.apache.wicket.model.CompoundPropertyModel;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.model.Model;
+import org.apache.wicket.model.ResourceModel;
+import org.apache.wicket.model.StringResourceModel;
+import org.apache.wicket.validation.IValidationError;
+import org.apache.wicket.validation.ValidationError;
+import org.apache.wicket.validation.validator.EmailAddressValidator;
+
 
 /**
  * This wizard shows some basic form use. It uses custom panels for the form
@@ -146,7 +147,7 @@
 		}
 
 		/**
-		 * @see wicket.extensions.wizard.WizardModel.ICondition#evaluate()
+		 * @see org.apache.wicket.extensions.wizard.WizardModel.ICondition#evaluate()
 		 */
 		public boolean evaluate()
 		{
@@ -209,7 +210,7 @@
 	}
 
 	/**
-	 * @see wicket.extensions.wizard.Wizard#onCancel()
+	 * @see org.apache.wicket.extensions.wizard.Wizard#onCancel()
 	 */
 	public void onCancel()
 	{
@@ -217,7 +218,7 @@
 	}
 
 	/**
-	 * @see wicket.extensions.wizard.Wizard#onFinish()
+	 * @see org.apache.wicket.extensions.wizard.Wizard#onFinish()
 	 */
 	public void onFinish()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/StaticWizard.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/StaticWizard.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/StaticWizard.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/StaticWizard.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/StaticWizard.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/StaticWizard.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/StaticWizard.java Tue Apr 10 11:54:24 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.wizard;
+package org.apache.wicket.examples.wizard;
 
-import wicket.extensions.wizard.StaticContentStep;
-import wicket.extensions.wizard.Wizard;
-import wicket.extensions.wizard.WizardModel;
+import org.apache.wicket.extensions.wizard.StaticContentStep;
+import org.apache.wicket.extensions.wizard.Wizard;
+import org.apache.wicket.extensions.wizard.WizardModel;
 
 /**
  * This is kind of the hello world example for wizards. It doesn't do anything
@@ -58,7 +58,7 @@
 	}
 
 	/**
-	 * @see wicket.extensions.wizard.Wizard#onCancel()
+	 * @see org.apache.wicket.extensions.wizard.Wizard#onCancel()
 	 */
 	public void onCancel()
 	{
@@ -66,7 +66,7 @@
 	}
 
 	/**
-	 * @see wicket.extensions.wizard.Wizard#onFinish()
+	 * @see org.apache.wicket.extensions.wizard.Wizard#onFinish()
 	 */
 	public void onFinish()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/StaticWizardWithPanels.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/StaticWizardWithPanels.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/StaticWizardWithPanels.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/StaticWizardWithPanels.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/StaticWizardWithPanels.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/StaticWizardWithPanels.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/StaticWizardWithPanels.java Tue Apr 10 11:54:24 2007
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.wizard;
+package org.apache.wicket.examples.wizard;
 
-import wicket.extensions.wizard.StaticContentStep;
-import wicket.extensions.wizard.Wizard;
-import wicket.extensions.wizard.WizardModel;
-import wicket.extensions.wizard.WizardStep;
+import org.apache.wicket.extensions.wizard.StaticContentStep;
+import org.apache.wicket.extensions.wizard.Wizard;
+import org.apache.wicket.extensions.wizard.WizardModel;
+import org.apache.wicket.extensions.wizard.WizardStep;
 
 /**
  * This is kind of the hello world example for wizards. It doesn't do anything
@@ -101,7 +101,7 @@
 	}
 
 	/**
-	 * @see wicket.extensions.wizard.Wizard#onCancel()
+	 * @see org.apache.wicket.extensions.wizard.Wizard#onCancel()
 	 */
 	public void onCancel()
 	{
@@ -109,7 +109,7 @@
 	}
 
 	/**
-	 * @see wicket.extensions.wizard.Wizard#onFinish()
+	 * @see org.apache.wicket.extensions.wizard.Wizard#onFinish()
 	 */
 	public void onFinish()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/User.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/User.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/User.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/User.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/User.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/User.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/User.java Tue Apr 10 11:54:24 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.wizard;
+package org.apache.wicket.examples.wizard;
 
 import java.util.HashSet;
 import java.util.Set;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
+
 
 /**
  * Domain class for the new user wizard example.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/WizardApplication.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/WizardApplication.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/WizardApplication.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/WizardApplication.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/WizardApplication.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/WizardApplication.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/WizardApplication.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.wizard;
+package org.apache.wicket.examples.wizard;
 
-import wicket.protocol.http.WebApplication;
+import org.apache.wicket.protocol.http.WebApplication;
 
 /**
  * Application class for the wizard example.
@@ -26,7 +26,7 @@
 public class WizardApplication extends WebApplication
 {
 	/**
-	 * @see wicket.Application#getHomePage()
+	 * @see org.apache.wicket.Application#getHomePage()
 	 */
 	public Class getHomePage()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/WizardPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/WizardPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/WizardPage.java?view=diff&rev=527247&p1=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/WizardPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/WizardPage.java&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/wicket/examples/wizard/WizardPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/examples/wizard/WizardPage.java Tue Apr 10 11:54:24 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.examples.wizard;
+package org.apache.wicket.examples.wizard;
 
 import java.lang.reflect.Constructor;
 
-import wicket.examples.WicketExamplePage;
-import wicket.extensions.wizard.Wizard;
+import org.apache.wicket.examples.WicketExamplePage;
+import org.apache.wicket.extensions.wizard.Wizard;
+
 
 /**
  * Page for displaying a wizard.

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/AnnotPage.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/AnnotPage.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/AnnotPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/AnnotPage.java Tue Apr 10 11:54:24 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.annot.web;
+package org.apache.wicket.spring.annot.web;
+
+import org.apache.wicket.extensions.markup.html.repeater.util.SortableDataProvider;
+import org.apache.wicket.spring.common.ContactDao;
+import org.apache.wicket.spring.common.web.ContactsDisplayPage;
+import org.apache.wicket.spring.injection.annot.SpringBean;
 
-import wicket.extensions.markup.html.repeater.util.SortableDataProvider;
-import wicket.spring.common.ContactDao;
-import wicket.spring.common.web.ContactsDisplayPage;
-import wicket.spring.injection.annot.SpringBean;
 
 
 public class AnnotPage extends ContactsDisplayPage {

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/ProxyDataProvider.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/ProxyDataProvider.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/ProxyDataProvider.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/ProxyDataProvider.java Tue Apr 10 11:54:24 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.annot.web;
+package org.apache.wicket.spring.annot.web;
 
-import wicket.model.IModel;
-import wicket.spring.common.Contact;
-import wicket.spring.common.ContactDao;
-import wicket.spring.common.web.ContactDataProvider;
+import org.apache.wicket.model.IModel;
+
+import org.apache.wicket.spring.common.Contact;
+import org.apache.wicket.spring.common.ContactDao;
+import org.apache.wicket.spring.common.web.ContactDataProvider;
 
 public class ProxyDataProvider extends ContactDataProvider {
 	private ContactDao dao;

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/ProxyModel.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/ProxyModel.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/ProxyModel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/annot/web/ProxyModel.java Tue Apr 10 11:54:24 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.annot.web;
+package org.apache.wicket.spring.annot.web;
 
-import wicket.spring.common.Contact;
-import wicket.spring.common.ContactDao;
-import wicket.spring.common.web.ContactDetachableModel;
+import org.apache.wicket.spring.common.Contact;
+import org.apache.wicket.spring.common.ContactDao;
+import org.apache.wicket.spring.common.web.ContactDetachableModel;
 
 public class ProxyModel extends ContactDetachableModel {
 	private ContactDao dao;

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/Contact.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/Contact.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/Contact.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/Contact.java Tue Apr 10 11:54:24 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.common;
+package org.apache.wicket.spring.common;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
 
 /**
  * domain object for demonstrations.

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactDao.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactDao.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactDao.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactDao.java Tue Apr 10 11:54:24 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.common;
+package org.apache.wicket.spring.common;
 
 import java.util.Iterator;
 

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactDaoImpl.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactDaoImpl.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactDaoImpl.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactDaoImpl.java Tue Apr 10 11:54:24 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.common;
+package org.apache.wicket.spring.common;
 
 import java.util.ArrayList;
 import java.util.Collections;

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactGenerator.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactGenerator.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactGenerator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/ContactGenerator.java Tue Apr 10 11:54:24 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.common;
+package org.apache.wicket.spring.common;
 
 import java.util.Collection;
 

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/QueryParam.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/QueryParam.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/QueryParam.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/QueryParam.java Tue Apr 10 11:54:24 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.common;
+package org.apache.wicket.spring.common;
 
 
 /**

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/BasePage.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/BasePage.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/BasePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/BasePage.java Tue Apr 10 11:54:24 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.common.web;
+package org.apache.wicket.spring.common.web;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.link.BookmarkablePageLink;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.link.BookmarkablePageLink;
 
 /**
  * Base page class. This is mainly here to provide some consistent look and feel

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactDataProvider.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactDataProvider.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactDataProvider.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactDataProvider.java Tue Apr 10 11:54:24 2007
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.common.web;
+package org.apache.wicket.spring.common.web;
 
 import java.util.Iterator;
 
-import wicket.extensions.markup.html.repeater.util.SortableDataProvider;
-import wicket.spring.common.ContactDao;
-import wicket.spring.common.QueryParam;
+import org.apache.wicket.extensions.markup.html.repeater.util.SortableDataProvider;
+import org.apache.wicket.spring.common.ContactDao;
+import org.apache.wicket.spring.common.QueryParam;
 
 /**
  * Base class for contact data provider implementations. This class implements

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactDetachableModel.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactDetachableModel.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactDetachableModel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactDetachableModel.java Tue Apr 10 11:54:24 2007
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.common.web;
+package org.apache.wicket.spring.common.web;
 
-import wicket.model.LoadableDetachableModel;
-import wicket.spring.common.Contact;
-import wicket.spring.common.ContactDao;
+import org.apache.wicket.model.LoadableDetachableModel;
+
+import org.apache.wicket.spring.common.Contact;
+import org.apache.wicket.spring.common.ContactDao;
 
 /**
  * Base class for contact detachable models. This class implements all necessary

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactsDisplayPage.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactsDisplayPage.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactsDisplayPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ContactsDisplayPage.java Tue Apr 10 11:54:24 2007
@@ -14,15 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.common.web;
+package org.apache.wicket.spring.common.web;
 
 import java.util.Arrays;
 
-import wicket.extensions.markup.html.repeater.data.table.DefaultDataTable;
-import wicket.extensions.markup.html.repeater.data.table.IColumn;
-import wicket.extensions.markup.html.repeater.data.table.PropertyColumn;
-import wicket.extensions.markup.html.repeater.util.SortableDataProvider;
-import wicket.model.Model;
+import org.apache.wicket.extensions.markup.html.repeater.data.table.DefaultDataTable;
+import org.apache.wicket.extensions.markup.html.repeater.data.table.IColumn;
+import org.apache.wicket.extensions.markup.html.repeater.data.table.PropertyColumn;
+import org.apache.wicket.extensions.markup.html.repeater.util.SortableDataProvider;
+import org.apache.wicket.model.Model;
+
 
 /**
  * Base class for the contact display page.

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ExampleApplication.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ExampleApplication.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/HomePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/HomePage.java Tue Apr 10 11:54:24 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.common.web;
+package org.apache.wicket.spring.common.web;
 
-import wicket.markup.html.link.BookmarkablePageLink;
-import wicket.spring.annot.web.AnnotPage;
-import wicket.spring.direct.web.DirectPage;
-import wicket.spring.proxy.web.ProxyPage;
+import org.apache.wicket.markup.html.link.BookmarkablePageLink;
+
+import org.apache.wicket.spring.annot.web.AnnotPage;
+import org.apache.wicket.spring.direct.web.DirectPage;
+import org.apache.wicket.spring.proxy.web.ProxyPage;
 
 /**
  * Home Page

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectDataProvider.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectDataProvider.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectDataProvider.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectDataProvider.java Tue Apr 10 11:54:24 2007
@@ -14,14 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.direct.web;
+package org.apache.wicket.spring.direct.web;
 
-import wicket.Application;
-import wicket.model.IModel;
-import wicket.spring.common.Contact;
-import wicket.spring.common.ContactDao;
-import wicket.spring.common.web.ContactDataProvider;
-import wicket.spring.common.web.ExampleApplication;
+import org.apache.wicket.Application;
+import org.apache.wicket.model.IModel;
+
+import org.apache.wicket.spring.common.Contact;
+import org.apache.wicket.spring.common.ContactDao;
+import org.apache.wicket.spring.common.web.ContactDataProvider;
+import org.apache.wicket.spring.common.web.ExampleApplication;
 
 public class DirectDataProvider extends ContactDataProvider {
 

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectModel.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectModel.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectModel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectModel.java Tue Apr 10 11:54:24 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.direct.web;
+package org.apache.wicket.spring.direct.web;
 
-import wicket.Application;
-import wicket.spring.common.Contact;
-import wicket.spring.common.ContactDao;
-import wicket.spring.common.web.ContactDetachableModel;
-import wicket.spring.common.web.ExampleApplication;
+import org.apache.wicket.Application;
+
+import org.apache.wicket.spring.common.Contact;
+import org.apache.wicket.spring.common.ContactDao;
+import org.apache.wicket.spring.common.web.ContactDetachableModel;
+import org.apache.wicket.spring.common.web.ExampleApplication;
 
 public class DirectModel extends ContactDetachableModel {
 

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectPage.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectPage.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/direct/web/DirectPage.java Tue Apr 10 11:54:24 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.direct.web;
+package org.apache.wicket.spring.direct.web;
 
-import wicket.extensions.markup.html.repeater.util.SortableDataProvider;
-import wicket.spring.common.web.ContactsDisplayPage;
+import org.apache.wicket.extensions.markup.html.repeater.util.SortableDataProvider;
+import org.apache.wicket.spring.common.web.ContactsDisplayPage;
 
 
 public class DirectPage extends ContactsDisplayPage {

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyDataProvider.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyDataProvider.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyDataProvider.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyDataProvider.java Tue Apr 10 11:54:24 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.proxy.web;
+package org.apache.wicket.spring.proxy.web;
 
-import wicket.model.IModel;
-import wicket.spring.common.Contact;
-import wicket.spring.common.ContactDao;
-import wicket.spring.common.web.ContactDataProvider;
+import org.apache.wicket.model.IModel;
+
+import org.apache.wicket.spring.common.Contact;
+import org.apache.wicket.spring.common.ContactDao;
+import org.apache.wicket.spring.common.web.ContactDataProvider;
 
 public class ProxyDataProvider extends ContactDataProvider {
 	private ContactDao dao;

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyModel.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyModel.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyModel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyModel.java Tue Apr 10 11:54:24 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.proxy.web;
+package org.apache.wicket.spring.proxy.web;
 
-import wicket.spring.common.Contact;
-import wicket.spring.common.ContactDao;
-import wicket.spring.common.web.ContactDetachableModel;
+import org.apache.wicket.spring.common.Contact;
+import org.apache.wicket.spring.common.ContactDao;
+import org.apache.wicket.spring.common.web.ContactDetachableModel;
 
 public class ProxyModel extends ContactDetachableModel {
 	private ContactDao dao;

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyPage.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyPage.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/proxy/web/ProxyPage.java Tue Apr 10 11:54:24 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.proxy.web;
+package org.apache.wicket.spring.proxy.web;
 
-import wicket.Application;
-import wicket.extensions.markup.html.repeater.util.SortableDataProvider;
-import wicket.spring.common.ContactDao;
-import wicket.spring.common.web.ContactsDisplayPage;
-import wicket.spring.common.web.ExampleApplication;
+import org.apache.wicket.Application;
+
+import org.apache.wicket.extensions.markup.html.repeater.util.SortableDataProvider;
+import org.apache.wicket.spring.common.ContactDao;
+import org.apache.wicket.spring.common.web.ContactsDisplayPage;
+import org.apache.wicket.spring.common.web.ExampleApplication;
 
 
 public class ProxyPage extends ContactsDisplayPage {

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/resources/applicationContext.xml
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/resources/applicationContext.xml?view=diff&rev=527247&r1=527246&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/resources/applicationContext.xml (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/resources/applicationContext.xml Tue Apr 10 11:54:24 2007
@@ -21,9 +21,9 @@
 	<!--
 		setup contact dao
 	-->
-	<bean id="contactDao" class="wicket.spring.common.ContactDaoImpl"/>
+	<bean id="contactDao" class="org.apache.wicket.spring.common.ContactDaoImpl"/>
 	
 	<!-- setup wicket application -->
-	<bean id="wicketApplication" class="wicket.spring.common.web.ExampleApplication"/>
+	<bean id="wicketApplication" class="org.apache.wicket.spring.common.web.ExampleApplication"/>
 
 </beans>

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/webapp/WEB-INF/web.xml
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/webapp/WEB-INF/web.xml?view=diff&rev=527247&r1=527246&r2=527247
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/webapp/WEB-INF/web.xml (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/webapp/WEB-INF/web.xml Tue Apr 10 11:54:24 2007
@@ -53,190 +53,190 @@
 
 	<filter>
 		<filter-name>AjaxPrototypeApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.ajax.prototype.PrototypeApplication</param-value>
+		  <param-value>org.apache.wicket.examples.ajax.prototype.PrototypeApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>AjaxApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 			<param-name>applicationClassName</param-name>
-			<param-value>wicket.examples.ajax.builtin.AjaxApplication</param-value>
+			<param-value>org.apache.wicket.examples.ajax.builtin.AjaxApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>HelloWorldApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.helloworld.HelloWorldApplication</param-value>
+		  <param-value>org.apache.wicket.examples.helloworld.HelloWorldApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>EchoApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.echo.EchoApplication</param-value>
+		  <param-value>org.apache.wicket.examples.echo.EchoApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>UnicodeConverterApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.unicodeconverter.UnicodeConverterApplication</param-value>
+		  <param-value>org.apache.wicket.examples.unicodeconverter.UnicodeConverterApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>HelloBrowserApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.hellobrowser.HelloBrowserApplication</param-value>
+		  <param-value>org.apache.wicket.examples.hellobrowser.HelloBrowserApplication</param-value>
 		</init-param>
 	</filter>
 
     <filter>
         <filter-name>StockQuoteApplication</filter-name>
-        <filter-class>wicket.protocol.http.WicketFilter</filter-class>
+        <filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
         <init-param>
             <param-name>applicationClassName</param-name>
-            <param-value>wicket.examples.stockquote.StockQuoteApplication</param-value>
+            <param-value>org.apache.wicket.examples.stockquote.StockQuoteApplication</param-value>
         </init-param>
     </filter>
     
 	<filter>
 		<filter-name>HangmanApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.hangman.HangmanApplication</param-value>
+		  <param-value>org.apache.wicket.examples.hangman.HangmanApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>FormInputApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.forminput.FormInputApplication</param-value>
+		  <param-value>org.apache.wicket.examples.forminput.FormInputApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>NestedApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.nested.NestedApplication</param-value>
+		  <param-value>org.apache.wicket.examples.nested.NestedApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>GuestBookApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.guestbook.GuestBookApplication</param-value>
+		  <param-value>org.apache.wicket.examples.guestbook.GuestBookApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>ImagesApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.images.ImagesApplication</param-value>
+		  <param-value>org.apache.wicket.examples.images.ImagesApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>LibraryApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.library.LibraryApplication</param-value>
+		  <param-value>org.apache.wicket.examples.library.LibraryApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>LinkomaticApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.linkomatic.LinkomaticApplication</param-value>
+		  <param-value>org.apache.wicket.examples.linkomatic.LinkomaticApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>NavomaticApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.navomatic.NavomaticApplication</param-value>
+		  <param-value>org.apache.wicket.examples.navomatic.NavomaticApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>PubApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.pub.PubApplication</param-value>
+		  <param-value>org.apache.wicket.examples.pub.PubApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>SignInApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.signin.SignInApplication</param-value>
+		  <param-value>org.apache.wicket.examples.signin.SignInApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>SignIn2Application</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.signin2.SignIn2Application</param-value>
+		  <param-value>org.apache.wicket.examples.signin2.SignIn2Application</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>UploadApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.upload.UploadApplication</param-value>
+		  <param-value>org.apache.wicket.examples.upload.UploadApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>EncodingsApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.encodings.EncodingsApplication</param-value>
+		  <param-value>org.apache.wicket.examples.encodings.EncodingsApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>TemplateApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.template.TemplateApplication</param-value>
+		  <param-value>org.apache.wicket.examples.template.TemplateApplication</param-value>
 		</init-param>
 		<init-param>
 		  <param-name>configuration</param-name>
@@ -246,109 +246,109 @@
 
 	<filter>
 		<filter-name>ComponentReferenceApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.compref.ComponentReferenceApplication</param-value>
+		  <param-value>org.apache.wicket.examples.compref.ComponentReferenceApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>RepeaterExamplesApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 			<param-name>applicationClassName</param-name>
-			<param-value>wicket.examples.repeater.RepeaterApplication</param-value>
+			<param-value>org.apache.wicket.examples.repeater.RepeaterApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>NiceUrlApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.niceurl.NiceUrlApplication</param-value>
+		  <param-value>org.apache.wicket.examples.niceurl.NiceUrlApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>FramesApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.frames.FramesApplication</param-value>
+		  <param-value>org.apache.wicket.examples.frames.FramesApplication</param-value>
 		</init-param>
 	</filter>
 	
 	<filter>
 		<filter-name>CustomResourceLoadingApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.customresourceloading.CustomResourceLoadingApplication</param-value>
+		  <param-value>org.apache.wicket.examples.customresourceloading.CustomResourceLoadingApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>WizardApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.wizard.WizardApplication</param-value>
+		  <param-value>org.apache.wicket.examples.wizard.WizardApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>CaptchaApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.captcha.CaptchaApplication</param-value>
+		  <param-value>org.apache.wicket.examples.captcha.CaptchaApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>BreadCrumbApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.breadcrumb.BreadCrumbApplication</param-value>
+		  <param-value>org.apache.wicket.examples.breadcrumb.BreadCrumbApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>StatelessApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 		  <param-name>applicationClassName</param-name>
-		  <param-value>wicket.examples.stateless.StatelessApplication</param-value>
+		  <param-value>org.apache.wicket.examples.stateless.StatelessApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>RolesAuthApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 			<param-name>applicationClassName</param-name>
-			<param-value>wicket.authorization.strategies.role.example.RolesApplication</param-value>
+			<param-value>org.apache.wicket.authorization.strategies.role.example.RolesApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>MyAuthenticatedWebApplication</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
 			<param-name>applicationClassName</param-name>
-			<param-value>wicket.authentication.example.MyAuthenticatedWebApplication</param-value>
+			<param-value>org.apache.wicket.authentication.example.MyAuthenticatedWebApplication</param-value>
 		</init-param>
 	</filter>
 
 	<filter>
 		<filter-name>SpringExample</filter-name>
-		<filter-class>wicket.protocol.http.WicketFilter</filter-class>
+		<filter-class>org.apache.wicket.protocol.http.WicketFilter</filter-class>
 		<init-param>
             <param-name>applicationFactoryClassName</param-name>
-            <param-value>wicket.spring.SpringWebApplicationFactory</param-value>
+            <param-value>org.apache.wicket.spring.SpringWebApplicationFactory</param-value>
 		</init-param>
 	</filter>
--- incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ExampleApplication.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/ExampleApplication.java Tue Apr 10 11:54:24 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.spring.common.web;
+package org.apache.wicket.spring.common.web;
 
-import wicket.spring.SpringWebApplication;
-import wicket.spring.common.ContactDao;
-import wicket.spring.injection.annot.SpringComponentInjector;
+import org.apache.wicket.spring.SpringWebApplication;
+import org.apache.wicket.spring.common.ContactDao;
+import org.apache.wicket.spring.injection.annot.SpringComponentInjector;
 
 /**
  * Application class for our examples
@@ -29,7 +29,7 @@
 public class ExampleApplication extends SpringWebApplication {
 
 	/**
 	 * this field holds a contact dao proxy that is safe to use in wicket
 	 * components
 	 */
 	private ContactDao contactDaoProxy;
@@ -29,7 +29,7 @@
 
 	/**
-	 * this field holds a contact dao proxy that is safe to use in wicket
+	 * this field holds a contact dao proxy that is safe to use in org.apache.wicket
 	 * components
 	 */

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/HomePage.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.5/wicket-examples/src/main/java/org/apache/wicket/spring/common/web/HomePage.java?view=diff&rev=527247&r1=527216&r2=527247
==============================================================================